@@ -337,7 +337,9 @@ void CvsConfig::readCfg()
    GEOM_WIDTH        = geom.width();
    GEOM_HEIGHT       = geom.height();
    
-   QRect desk = QApplication::desktop()->screenGeometry();
+   //take the size of the desktop (including all screens if virtual desktop)
+   //and make sure the app window is within its boundaries
+   QRect desk = QApplication::desktop()->screen ()->rect ();
    if (GEOM_WIDTH > desk.width())   GEOM_WIDTH  = desk.width();
    if (GEOM_HEIGHT > desk.height()) GEOM_HEIGHT = desk.height();
    
