@@ -104,6 +104,7 @@ class CvsConfig
    static const char Version[];
    static const char Debug[];
    static const char LogLevel[];
+   static const char VeryFirstStart[];
    static const char CheckStatusIntervall[];
    static const char CheckStatusLevel[];
    static const char ProgressIntervall[];
@@ -257,6 +258,12 @@ public:
    bool setLogLevel(int level) {
       return m_pSettings->writeEntry(LogLevel, level);
    }
+   bool getVeryFirstStart(bool bVeryFirstStart) {
+      return m_pSettings->readBoolEntry(VeryFirstStart, bVeryFirstStart);
+   }
+   void setVeryFirstStart(bool bVeryFirstStart) {
+      m_pSettings->writeEntry(VeryFirstStart, bVeryFirstStart);
+   }
    QString getCvsPassPath() {
       return m_pSettings->readEntry(cvsPassFile, CVSPASSPATH);
    }
@@ -562,11 +569,7 @@ public:
       m_pSettings->writeEntry(DateTimeFormat,format);
    }
    bool get0AsParent() {
-#ifdef Q_WS_WIN
-      return m_pSettings->readBoolEntry(Use0AsParent, false);
-#else
       return m_pSettings->readBoolEntry(Use0AsParent, true);
-#endif
    }
    void set0AsParent(bool state) {
       m_pSettings->writeEntry(Use0AsParent,state);
