@@ -1,6 +1,6 @@
 /****************************************************************************
 **
-** Copyright (C) 2004-2006 Tilo Riemer <riemer@crossvc.com>,
+** Copyright (C) 2004-2007 Tilo Riemer <riemer@crossvc.com>,
 **                         Frank Hemer <frank@hemer.org>
 **
 **
@@ -160,8 +160,8 @@ void CEditProfilesDialogImpl::fillCtrls(const bool bEdit)
       m_pUserBox->setCurrentText("");
       m_pServerBox->setCurrentText("");
       m_pRepositoryBox->setCurrentText("");
-      m_pAccessBox->setCurrentItem(SSPI);
-      accessMode(SSPI);
+      m_pAccessBox->setCurrentItem(LOCAL);
+      accessMode(LOCAL);
       m_pSshSettingsBox->setCurrentItem(NOSSH);
    }
 }
