@@ -1,6 +1,6 @@
 /****************************************************************************
 **
-** Copyright (C) 2004-2006 Frank Hemer <frank@hemer.org>,
+** Copyright (C) 2004-2007 Frank Hemer <frank@hemer.org>,
 **                         Tilo Riemer <riemer@crossvc.com>
 **
 **
@@ -117,24 +117,6 @@ Import * Import::setup(const QIconSet &whatsThisIconSet, QWidget* parent, CvsDir
    }
 
    return NULL;
-
-//    if (dir->getType() == DirBase::Cvs) {
-
-//       Import * p = new Import(whatsThisIconSet, parent, workBench, dir, mode);
-
-      //       p->m_dlg = new Dialog();
-
-//       connect(p->m_dlg,SIGNAL(accept()),p,SLOT(acceptCvs()));
-//       connect(p->m_dlg,SIGNAL(reject()),p,SLOT(reject()));
-//       p->m_dlg->show();
-
-//       return p;
-
-//    } else {
-
-//       qDebug("Import: Method not implemented");
-//       return NULL;
-//    }
 }
 
 Import::Import(const QIconSet &whatsThisIconSet, QWidget* parent, CvsDirListView * workBench, DirBase * dir, int mode)
@@ -142,12 +124,16 @@ Import::Import(const QIconSet &whatsThisIconSet, QWidget* parent, CvsDirListView
       m_parent(parent),
       m_workBench(workBench),
       m_dir(dir),
+      m_bCreateCvsDirs(false),
+      m_sshAccess(NOSSH),
       m_dlg(NULL),
       m_mode(mode)
 {
    connect(this,SIGNAL(deleteObject(QObject *)),parent,SLOT(slot_deleteObject(QObject *)));
    connect(this,SIGNAL(checkTree(DirBase *)),parent,SLOT(slot_checkStatusOfTree(DirBase *)));
+   connect(this,SIGNAL(showInfo(const QString&,const QString&)),parent,SLOT(showInfo(const QString&,const QString&)));
    connect(this,SIGNAL(showWarning(const QString&,const QString&)),parent,SLOT(showWarning(const QString&,const QString&)));
+   connect(this,SIGNAL(addCheckedOutProject(QString,QString,int)),parent,SLOT(slot_addCheckedOutProject(QString,QString,int)));
 }
 
 Import::~Import() {
@@ -172,7 +158,7 @@ void Import::acceptCvs() {
       return;
    }
 
-   QString dir = localDir.absPath();
+   m_localDir = localDir.absPath();
    QString module = dlg->module();
    QString comment = dlg->comment();
    QString user = dlg->user();
@@ -183,9 +169,9 @@ void Import::acceptCvs() {
    QString tagR = dlg->tagR();
    int mode = dlg->mode();
    int rshMode = dlg->rshMode();
-   int sshAccess = dlg->getSshPreset();
+   m_sshAccess = dlg->getSshPreset();
    bool keepFTime = dlg->getKeepFTime();
-   bool createDirs = dlg->getCreateDirs();
+   m_bCreateCvsDirs = dlg->getCreateDirs();
    QStringList ignoreWildcards = dlg->getIgnoreWildcards();
    QStringList binaryWildcards = dlg->getBinaryWildcards();
 
@@ -198,7 +184,7 @@ void Import::acceptCvs() {
   
    //modify application-wide lists
    adaptQStringList(module,&MODULEHISTORYLIST,HistorySize::g_profiles);
-   adaptQStringList(dir.left(dir.findRev("/")),&WORKDIRHISTORYLIST,HistorySize::g_workdirs);
+   adaptQStringList(m_localDir.left(m_localDir.findRev("/")),&WORKDIRHISTORYLIST,HistorySize::g_workdirs);
    adaptQStringList(tagV,&s_vendorTagList,20);
    adaptQStringList(tagR,&s_releaseTagList,20);
    adaptQStringList(user, &cvsUsers, HistorySize::g_profiles);
@@ -209,18 +195,18 @@ void Import::acceptCvs() {
    bUseSsh = false;
    bUseSshAgent = false;
    bUseSshAgentVars = false;
-   switch( sshAccess) {
+   switch( m_sshAccess) {
       case USESSH: {
-	 bUseSsh = true;
-	 break;
+            bUseSsh = true;
+            break;
       }
       case USESSHAGENT: {
-	 bUseSshAgent = true;
-	 break;
+            bUseSshAgent = true;
+            break;
       }
       case USESSHAGENTVARS: {
-	 bUseSshAgentVars = true;
-	 break;
+            bUseSshAgentVars = true;
+            break;
       }
    }
   
@@ -229,16 +215,16 @@ void Import::acceptCvs() {
       //set CVSROOT for sspi mode
       cvsRoot = ":sspi:";
       needcvsroot = true;
-   }else if(mode == PSERVER) { //password server
+   } else if(mode == PSERVER) { //password server
       //set CVSROOT for pserver mode
       cvsRoot = ":pserver:";
       needcvsroot = true;
    } else if(mode == RSH) {//remote shell access
       needcvsroot = true;
       if(rshMode == RSH_EXT) {
-	 cvsRoot = ":ext:";
+         cvsRoot = ":ext:";
       } else {
-	 cvsRoot = ":server:";
+         cvsRoot = ":server:";
       }
    }
    if (server.find(':') == -1) server += ":";
@@ -250,7 +236,7 @@ void Import::acceptCvs() {
    files += " import ";
    
    if (keepFTime) files += "-d ";
-   if (createDirs) files += "-C ";
+   if (m_bCreateCvsDirs) files += "-C ";
     
   
    //ignore files:
@@ -277,8 +263,8 @@ void Import::acceptCvs() {
    files += masqWs(module) + " " + tagV + " " + tagR;
    QString topModule = QString::null;
 
-   callInteractive( topModule, dir, cvsRoot,
-	 files, CVS_IMPORT_CMD, tmpCvsRsh);
+   callInteractive( topModule, m_localDir, cvsRoot,
+      files, CVS_IMPORT_CMD, tmpCvsRsh);
 }
 
 void Import::reject() {
@@ -293,7 +279,8 @@ void Import::cvsCallFinished() {
    QApplication::restoreOverrideCursor();
 }
 
-void Import::afterCall(int cmd,CvsBuffer*,bool failed) {
+void Import::afterCall(int cmd, CvsBuffer *buf, bool failed) {
+   
    cvsCallFinished();
    if (failed) {
       reject();
@@ -301,13 +288,80 @@ void Import::afterCall(int cmd,CvsBuffer*,bool failed) {
    }
    switch( cmd) {
       case NOOP: {
-	 break;
+         break;
       }
       case CVS_IMPORT_CMD: {
-	 break;
+         
+         //check if cvs import succeeded
+         bool test = false;
+         unsigned int len = (*buf).numLines();
+         for ( unsigned int i = outputLineOffset; i<len; i++) {
+            if ((*buf).textLine(i).startsWith("No conflicts created")) {
+               test = true;
+               break;
+            }
+         }
+         if (!test) {
+            emit showWarning(tr("Warning"),tr("Import failed"));
+            reject();
+            return;
+         }
+
+         if (m_bCreateCvsDirs) {
+            //cvs dir is already in workbench?
+            QString topProjectDir = "";
+            QString subProjectDir = "";
+            bool found = false;
+            DirBase * myChild = NULL;
+               
+            QString importDir = m_localDir;
+            int pos = importDir.length();
+            do {
+                  
+               pos = importDir.findRev("/");
+               importDir.truncate(pos);
+                  
+               if ( (myChild = m_workBench->find(importDir)) ) {
+                     
+                  if (myChild->isAnalyzed()) {
+                        
+                     QString dirToAdd = m_localDir;
+                     dirToAdd = dirToAdd.left(dirToAdd.find("/",myChild->fullName().length()+1));
+                     DirBase * unanalyzedDir = myChild->addDir(dirToAdd);
+                     if (unanalyzedDir && myChild->isOpen()) {//will not be analyzed on open() because it is already open
+                        myChild->setOpen(TRUE);
+                     }
+                     if (myChild->isSelected()) {
+                        myChild->activateItem(TRUE);//reread files
+                     } else {
+                        m_workBench->setSelected(myChild,TRUE);//reread files
+                     }
+                  }
+                     
+                  emit showInfo( tr("Import Info"), tr("This project subdir has been added.") );
+                  topProjectDir = myChild->topDir()->shortName();
+                  DirBase * tmp = m_workBench->find(m_localDir);
+                  if (tmp) {
+                     subProjectDir = tmp->topControlledDir()->relativeName();
+                     projectSettings->set(subProjectDir, SSHACCESS, m_sshAccess);
+                  }
+                  found = true;
+               }
+                  
+            } while ( !found && (pos > -1));
+               
+            if ( !found) {
+               QString path = m_localDir.left(m_localDir.findRev("/"));
+               QString name = m_localDir.mid(m_localDir.findRev("/") + 1);
+               emit addCheckedOutProject(path, name, m_sshAccess);
+            }
+         
+         }
+         
+         break;
       }
       default: {
-	 qDebug("Import::afterCall: Unknown cmd");
+         qDebug("Import::afterCall: Unknown cmd");
       }
    }
    reject();
