@@ -1,6 +1,6 @@
 /****************************************************************************
 **
-** Copyright (C) 2002-2006 Frank Hemer <frank@hemer.org>,
+** Copyright (C) 2002-2007 Frank Hemer <frank@hemer.org>,
 **                         Tilo Riemer <riemer@crossvc.com>
 **
 **
@@ -180,25 +180,25 @@ ImportDialogImpl::ImportDialogImpl( QString* defaultProfile,
    QString rootDir;
    if (analyzeCVSROOT(connectMethod, userName, passwd, host, port, rootDir)) {
       if (!host.isNull()) {
-	 host += ":" + QString::number(port);
+         host += ":" + QString::number(port);
       }
       m_UserBox->setCurrentText(userName);
       m_ServerBox->setCurrentText(host);
       m_RepositoryBox->setCurrentText(rootDir);
       if (connectMethod.startsWith("local") || connectMethod.startsWith("fork")) {
-	 m_AccessBox->setCurrentItem(2);
+         m_AccessBox->setCurrentItem(2);
       } else if (connectMethod.startsWith("pserver")) {
-	 m_AccessBox->setCurrentItem(0);
+         m_AccessBox->setCurrentItem(0);
       } else if (connectMethod.startsWith("sspi")) {
          m_AccessBox->setCurrentItem(3);
       } else {
-	 m_AccessBox->setCurrentItem(3);
+         m_AccessBox->setCurrentItem(2);
       }
    } else {
       m_UserBox->setCurrentText("");
       m_ServerBox->setCurrentText("");
       m_RepositoryBox->setCurrentText("");
-      m_AccessBox->setCurrentItem(3);
+      m_AccessBox->setCurrentItem(2);
    }
 
    m_CommitInfo->setText("");
@@ -220,10 +220,10 @@ ImportDialogImpl::ImportDialogImpl( QString* defaultProfile,
    if(cvsignore.open(IO_ReadOnly)) {
       QTextStream ignoreStream(&cvsignore); 
       while(!ignoreStream.eof()) {
-	 QString line = ignoreStream.readLine().simplifyWhiteSpace();
-	 if (!line.isEmpty()) {
-	    m_ignoreList.append(line);
-	 }
+         QString line = ignoreStream.readLine().simplifyWhiteSpace();
+         if (!line.isEmpty()) {
+            m_ignoreList.append(line);
+         }
       }
       cvsignore.close();
    }
@@ -232,6 +232,11 @@ ImportDialogImpl::ImportDialogImpl( QString* defaultProfile,
 
    m_binaryList = BINARYFILESPECLIST;
 
+   if (CVSVERSION != "cvsnt") {
+      m_CreateDirs->setEnabled(false);
+      m_CreateDirs->setChecked(false);
+   }
+   
    if (!m_defaultProfile->isEmpty()) {
       setDefaultProfile(*m_defaultProfile);
    }
