@@ -99,6 +99,7 @@
 #include "noncvslistview.h"
 #include "cvsignorelistview.h"
 #include "cvsconfig.h"
+#include "cvsconfig_old.h"
 #include "login.h"
 #include "LinCVSLog.h"
 #include "TextEncoder.h"
@@ -110,7 +111,7 @@ const bool CvsControl::OVERRIDE = TRUE;
 //----------------------------------------------------------------------------
 
 CvsControl::CvsControl( QString startUpDir)
-   : CMainWindow(0, "LinCVS main window", WType_TopLevel | WDestructiveClose)
+   : CMainWindow(0, "CrossVC main window", WType_TopLevel | WDestructiveClose)
 {
    conf = 0;
    KILLED = false;
@@ -209,6 +210,14 @@ void CvsControl::readSettings() {
 
    conf = new CvsConfig;
 
+   // check for old lincvs config
+   if (Misc::g_bVeryFirstStart) {
+      // try to load old config --> creation of object reads old config
+      CvsConfigOld oldConf;
+   }
+
+   Misc::g_bVeryFirstStart = false;
+
    expurgateProjectSettings();
 
    if (ExtApps::g_cvsRsh.path.isEmpty() && (!tmpCvsRsh.isEmpty())) {
@@ -854,7 +863,7 @@ void CvsControl::slot_selectSubDir(DirBase ** pdir, QString subDir) {
       } else {//adding of dir failed
 	 *pdir = prevDir;
 	 (*pdir)->activateItem(FALSE);
-	 QString caption = tr("LinCVS - Error");
+	 QString caption = tr("CrossVC - Error");
 	 QString msg = tr("Adding of directory %1 failed!\nMaybe permission denied.");
 	 showWarning( caption, msg.arg(subDir) );
       }
@@ -1110,7 +1119,7 @@ void CvsControl::slot_debug() {
       QTextStream s(&file);                        // serialize using f
       s << "----------start debug log------------\n";
       s << "Date: "+QDateTime::currentDateTime().toString(Qt::ISODate)+"\n";
-      s << "LinCVS version: "+getVersion()+"\n";
+      s << "CrossVC version: "+getVersion()+"\n";
 #ifdef Q_WS_WIN
       s << "for Windows\n";
 #else
@@ -2109,9 +2118,9 @@ void CvsControl::callInteractiveCmd( QString& topModule,
    unsigned int pwdPos = 0;
    unsigned int pwdLen = 0;
 
-   if (method == "pserver") { // password server
+   if ((method == "pserver") || (method == "sspi")) { // password server OR sspi
 
-      Debug::g_pLog->log(Debug::LL_INFO, "access method: pserver");
+      Debug::g_pLog->log(Debug::LL_INFO, "access method: pserver OR sspi");
 
       if (passwd.isNull() && !isInCvsPass(cvsRootLine))
 	 {
@@ -2125,7 +2134,7 @@ void CvsControl::callInteractiveCmd( QString& topModule,
 	    //if (!parentWidget) parentWidget = LookAndFeel::g_b0AsParent ? 0 : this;
 	    if (!parentWidget) parentWidget = this;
 	    QString pwd = QInputDialog::getText("Enter CVS password",
-		  user + "@" + host + ":" + QString::number(port) + rootDir, QLineEdit::Password,
+		  ":" + method + ":" + user + "@" + host + ":" + QString::number(port) + rootDir, QLineEdit::Password,
 		  QString::null, &ok, parentWidget, "Password Dialog");
 
 	    if (blocked) blockGUI(true);
@@ -2139,7 +2148,7 @@ void CvsControl::callInteractiveCmd( QString& topModule,
 
 	    if (!blocked) blockGUI(true);
 
-	    Login *l = new Login( m_pMessages, user, host, port, rootDir);
+	    Login *l = new Login(m_pMessages, method, user, host, port, rootDir);
 	    l->doLogin(pwd);
 	    delete l;
 
@@ -2230,7 +2239,7 @@ void CvsControl::callInteractiveCmd( QString& topModule,
 	    //if (!parentWidget) parentWidget = LookAndFeel::g_b0AsParent ? 0 : this;
 	    if (!parentWidget) parentWidget = this;
 	    QString pwd = QInputDialog::getText("Enter CVS password",
-		  user + "@" + host + ":" + QString::number(port) + rootDir, QLineEdit::Password,
+		  ":" + method + ":" + user + "@" + host + ":" + QString::number(port) + rootDir, QLineEdit::Password,
 		  QString::null, &ok, parentWidget, "Password Dialog");
 
 	    if (blocked) blockGUI(true);
