@@ -118,7 +118,7 @@ static const QString whatsThisTextInt[]= {
    /* exit */
    QObject::tr("<html>"
 	 "<p>"
-	 "Exit LinCVS."
+	 "Exit CrossVC."
 	 "</p>"
 	 "</html>"),
 
@@ -173,7 +173,7 @@ static const QString whatsThisTextInt[]= {
 	 "Push this button to enable the auto update mechanism.<br>"
 	 "All projects configured to use the Auto-Update feature will be updated automatically "
 	 "every X (e.g. every minute). X is the time interval you have set in "
-	 "<nobr><b>Config -> Settings ... -> LinCVS Options -> AutoUpdate</b></nobr>.<br>"
+	 "<nobr><b>Config -> Settings ... -> CrossVC Options -> AutoUpdate</b></nobr>.<br>"
 	 "The autoupdate property can be set with <nobr><b>Directory -> Project -> Properties</b></nobr>."
 	 "</p>"
 	 "</html>"),
@@ -308,7 +308,7 @@ static const QString whatsThisText[]= {
    QObject::tr("<html>"
 	 "<p>"
 	 "<u><b>This is your workbench:</b></u><br>"
-	 "In this area all the folders are listed that you have already checked out with LinCVS. "
+	 "In this area all the folders are listed that you have already checked out with CrossVC. "
 	 "Additionally all folders you have added with the command <br>"
 	 "<b>Project -> Add to Workbench ...</b><br>are listed here.<br>"
 	 "</p>"
@@ -340,8 +340,8 @@ static const QString whatsThisText[]= {
 	 "<u><b>These are the controlled contents of the selected folder:</b></u><br>"
 	 "Provided a folder is selected from the workbench, in this area all <em>checked out</em> " 
 	 "files are listed together with some status information described in the headline. "
-	 "This information is updated periodically due to the timer settings. LinCVS keeps track "
-	 "with changes even if they are caused from outside LinCVS, i.e. by a cvs commandline call. "
+	 "This information is updated periodically due to the timer settings. CrossVC keeps track "
+	 "with changes even if they are caused from outside CrossVC, i.e. by a cvs commandline call. "
 	 "After clicking on a file with the right mouse button a contextual menu is opened."
 	 "</p>"
 	 "<p>"
