@@ -892,19 +892,19 @@ DirBase * Directory::searchDirOfPath(QString path, bool findVirtual) {
       return NULL;
    }
    if (path.compare(m_fullName) == 0) {
-      return this;   //its my path :-)
+      return this;   //it's my path :-)
    }
   
    if (path.find(m_fullName+"/") == 0) {//is subdir
       Directory * myChild = firstChild();
       Directory * result;
       while (myChild) {
-	 if ( (result = dyncast_dir(myChild->searchDirOfPath(path, findVirtual))) ) {
-	    return result;
-	 }
-	 else {
-	    myChild = myChild->nextSibling();
-	 }
+         if ( (result = dyncast_dir(myChild->searchDirOfPath(path, findVirtual))) ) {
+            return result;
+         }
+         else {
+            myChild = myChild->nextSibling();
+         }
       }
    }
    return NULL;
