@@ -400,7 +400,7 @@ bool CvsRootDirView::ckReadable( QString& path, bool addExt )
 {
   if (QDir(path).exists()) {
     if (!(QDir(path).isReadable())) {
-      QMessageBox::warning( this, "LinCVS - Directory Error",
+      QMessageBox::warning( this, "CrossVC - Directory Error",
                             QString("Unable to read\n  ")+path+"\nCheck permissions" );
       return FALSE;
     }
@@ -410,7 +410,7 @@ bool CvsRootDirView::ckReadable( QString& path, bool addExt )
     /*! should be a filename then, and must prior append the rcs extension */
     if (addExt) path.append(RcsExt);
     if (!(QFileInfo(path).isReadable())) {
-      QString caption = "LinCVS - ";
+      QString caption = "CrossVC - ";
       caption +=  tr("File Error");
       QString msg = tr("Unable to read");
       msg += "\n%1\n";
