@@ -379,7 +379,7 @@ bool extractCVSROOT( QString rootline,
       QString& path) {
 
    /* Access method specified, as in
-    * "cvs -d :(gserver|kserver|pserver)[;params...]:[[[user][:password]@]host[:[port]]]/path",
+    * "cvs -d :(gserver|kserver|pserver|sspi)[;params...]:[[[user][:password]@]host[:[port]]]/path",
     * "cvs -d [:(ext|server)[;params...]:][[[user]@]host[:]]/path",
     * "cvs -d :local[;params...]:e:\path",
     * "cvs -d :fork[;params...]:/path".
@@ -807,14 +807,20 @@ void createTmpDir()
    QDir home = QDir::home();
    QDir tempDir;
 
+   Misc::g_bVeryFirstStart = false;
+
    QFileInfo tmp(home, ".crossvc");
    if (tmp.exists()) {
       if (!tmp.isDir()) {
-	 QFile f(tmp.absFilePath());
-	 f.remove();  //we must check the result of remove!!!
-	 tempDir.mkdir(tmp.absFilePath());
+         QFile f(tmp.absFilePath());
+         f.remove();  //we must check the result of remove!!!
+         tempDir.mkdir(tmp.absFilePath());
+         Misc::g_bVeryFirstStart = true;
       }
-   } else tempDir.mkdir(tmp.absFilePath());
+   } else {
+      tempDir.mkdir(tmp.absFilePath());
+      Misc::g_bVeryFirstStart = true;
+   }
  
    chmod(tmp.absFilePath(), 0700);
 
