@@ -136,6 +136,7 @@ const int RSH_SERVER          = 32;
 const int PSERVER      =  0;
 const int RSH          =  1;
 const int LOCAL        =  2;
+const int SSPI         =  3;
 
 const int NOSSH            = 0;
 const int USESSH           = 1;
@@ -355,6 +356,7 @@ namespace Misc {
 #ifdef Q_WS_X11
    EXTERN QString g_rcPath;  // additional rcpath
 #endif
+   EXTERN bool    g_bVeryFirstStart;
 }
 
 namespace Mapping {
