@@ -484,8 +484,8 @@ void SettingsDialogImpl::apply()
       if (!iconDir.isEmpty()) {
 	 loadPixmapsFromDisk(iconDir);
 
-	 QMessageBox::information(this, tr("LinCVS - Information"), 
-	       tr("LinCVS can't update all icons before next restart."), 0);
+	 QMessageBox::information(this, tr("CrossVC - Information"), 
+	       tr("CrossVC can't update all icons before next restart."), 0);
       }
    }
 
@@ -609,8 +609,8 @@ void SettingsDialogImpl::apply()
    if (m_pUseDirWatch->isEnabled()) {
 
       if (m_pUseDirWatch->isChecked() && !DirWatch::b_useDirWatch) {
-	 QMessageBox::information(this, tr("LinCVS - Information"), 
-	       tr("You need to restart LinCVS to activate dir monitoring."), 0);
+	 QMessageBox::information(this, tr("CrossVC - Information"), 
+	       tr("You need to restart CrossVC to activate dir monitoring."), 0);
       }
       DirWatch::b_useDirWatch = m_pUseDirWatch->isChecked();
    }
@@ -1118,10 +1118,10 @@ void SettingsDialogImpl::fillLangEnv()
 void SettingsDialogImpl::applyLangEnv()
 {
    QString newCoder;
-   QString errMsg = tr("LinCVS could not create the desired codec %1 for %2");
+   QString errMsg = tr("CrossVC could not create the desired codec %1 for %2");
    errMsg += "\n";
-   errMsg += "LinCVS uses the old codec.";
-   
+   errMsg += "CrossVC uses the old codec.";
+
    QString tmp = m_pCodecForEncoding->currentText();
    int pos = tmp.find(" (");
    if (pos > -1) newCoder = tmp.left(pos);
@@ -1130,9 +1130,9 @@ void SettingsDialogImpl::applyLangEnv()
       I18n::g_pTextEncoder->setEncoder(newCoder);
       I18n::g_nameOfEncoder = newCoder;
    } catch (XI18n) {
-      QMessageBox::critical(this, tr("LinCVS - Error"), 
-      errMsg.arg(newCoder).arg("encoding"), 0);
-      
+      QMessageBox::critical(this, tr("CrossVC - Error"), 
+	    errMsg.arg(newCoder).arg("encoding"), 0);
+
       const QPtrVector<TextCodec::SCodec>* pCodecs = I18n::g_pTextEncoder->supportedCodecs();
       unsigned int i;
       for (i = 0; i < pCodecs->size(); i++) {
@@ -1148,9 +1148,9 @@ void SettingsDialogImpl::applyLangEnv()
       I18n::g_pTextDecoder->setGeneralDecoder(newCoder);
       I18n::g_nameOfDecoder = newCoder;
    } catch (XI18n) {
-      QMessageBox::critical(this, tr("LinCVS - Error"), 
-      errMsg.arg(newCoder).arg("decoding"), 0);
-      
+      QMessageBox::critical(this, tr("CrossVC - Error"), 
+	    errMsg.arg(newCoder).arg("decoding"), 0);
+
       const QPtrVector<TextCodec::SCodec>* pCodecs = I18n::g_pTextDecoder->supportedCodecs();
       unsigned int i;
       for (i = 0; i < pCodecs->size(); i++) {
